#include <gtk/gtk.h>

// Function called when the quit button is clicke
static void
doneClicked(GtkWidget *button, GtkWidget *window) {
  gtk_widget_destroy(window);   // closes the main window
}

// This function is called when the gtk+ main loop starts and there
// are no command line arguments
static void
activate (GtkApplication *app,
          gpointer        user_data)
{
  GtkWidget *window;
  GtkWidget *grid;
  GtkWidget *quitButton;

  /* create a new window, and set its title */
  window = gtk_application_window_new (app);
  gtk_window_set_title (GTK_WINDOW (window), "ex04");
  gtk_container_set_border_width (GTK_CONTAINER (window), 10);

  /* Here we construct the container that is going pack our buttons */
  grid = gtk_grid_new ();
  /* Pack the container in the window */
  gtk_container_add (GTK_CONTAINER (window), grid);

  // Create the quit button and register handler for it
  quitButton = gtk_button_new_with_label ("Quit");
  g_signal_connect(quitButton, "clicked", G_CALLBACK (doneClicked), window);

  /* Place the quit button in the grid cell (0, 0), and make it fill
   * just 1 cell horizontally and vertically (ie no spanning)
   */
  gtk_grid_attach (GTK_GRID (grid), quitButton, 0, 0, 1, 1);

  /* Now that we are done packing our widgets, we show them all
   * in one go, by calling gtk_widget_show_all() on the window.
   * This call recursively calls gtk_widget_show() on all widgets
   * that are contained in the window, directly or indirectly.
   */
  gtk_widget_show_all (window);
}

int
main (int    argc,
      char **argv)
{
  GtkApplication *app;
  int status;

  // If you supply NULL to gtk_application_new you can run more than one instance
  // of the app at a time.  If you supply a correctly formated app name
  // (like "edu.washington.cs.cse333.ex04"), gtk+ will ensure that only a single
  // process is running, with a new main window being created for each invocation
  app = gtk_application_new (NULL, G_APPLICATION_FLAGS_NONE);
  g_signal_connect (app, "activate", G_CALLBACK (activate), NULL);
  // Control is given to the gtk+ event loop.  It doesn't return until
  // the app is terminating.
  status = g_application_run (G_APPLICATION (app), argc, argv);
  g_object_unref (app);

  return status;
}
